import { defineProperty as _defineProperty } from './_virtual/_rollupPluginBabelHelpers.mjs';
import { AssetNotFoundError } from './errors.mjs';

const DEFAULT_BASE_URL = 'https://mockstorage.example.com/';
class MockStorage {
  constructor(options) {
    _defineProperty(this, "cache", {});
    this.baseUrl = options?.baseUrl ?? DEFAULT_BASE_URL;
  }
  async uploadOne(file) {
    const uri = `${this.baseUrl}${file.uniqueName}`;
    this.cache[uri] = file;
    return uri;
  }
  async upload(files) {
    return Promise.all(files.map(file => this.uploadOne(file)));
  }
  async download(uris) {
    return Promise.all(uris.map(uri => this.downloadOne(uri)));
  }
  async downloadOne(uri) {
    const file = this.cache[uri];
    if (!file) {
      throw new AssetNotFoundError(uri);
    }
    return file;
  }
}

export { MockStorage };
//# sourceMappingURL=MockStorage.mjs.map
